[gnome-control-center] display: Do not add preferred mode to drop down in clone mode.



commit 15bcc03b4063bad9c3f338ca5fd37e21c0ced779
Author: Cyrus Lien <cyrus lien canonical com>
Date:   Tue Aug 7 14:23:21 2012 +0800

    display: Do not add preferred mode to drop down in clone mode.
    
    Use preferred resolution to switch to mirror mode will popup error
    messages if preferred resolution is not a common resolution.
    
    https://bugzilla.gnome.org/show_bug.cgi?id=680969

 panels/display/cc-display-panel.c |    6 ++++--
 1 files changed, 4 insertions(+), 2 deletions(-)
---
diff --git a/panels/display/cc-display-panel.c b/panels/display/cc-display-panel.c
index e2b2a29..b7a92dc 100644
--- a/panels/display/cc-display-panel.c
+++ b/panels/display/cc-display-panel.c
@@ -808,8 +808,10 @@ rebuild_resolution_combo (CcDisplayPanel *self)
   for (i = 0; modes[i] != NULL; ++i)
     add_mode (self, modes[i], output_width, output_height, preferred_id);
 
-  /* And force the preferred mode in the drop-down */
-  add_mode (self, mode, output_width, output_height, preferred_id);
+  /* And force the preferred mode in the drop-down (when not in clone mode)
+   * https://bugzilla.gnome.org/show_bug.cgi?id=680969 */
+  if (!gnome_rr_config_get_clone (self->priv->current_configuration))
+   add_mode (self, mode, output_width, output_height, preferred_id);
 
   current = make_resolution_string (output_width, output_height);
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]